'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.noUntweakedErrorMessage = exports.queryNoNestedArraysErrorMessage = exports.queryChildElementIsValidTypeErrorMessage = exports.queryElementIsValidTypeErrorMessage = exports.queryNoElementsErrorMessage = exports.invalidFeatureErrorMessage = exports.shouldSeparateQueriesErrorMessage = exports.invalidDimensionsUnitErrorMessage = exports.invalidDefaultMediaTypeErrorMessage = exports.invalidBaseFontSizeErrorMessage = exports.invalidBreakpointSetValueErrorMessage = exports.invalidMediaTypeErrorMessage = exports.sameBreakpointsForBetweenErrorMessage = exports.missingBreakpointErrorMessage = exports.mssingBreakpointMapErrorMessage = exports.emptyBreakpointSetErrorMessage = exports.invalidBreakpointNamesErrorMessage = exports.emptyBreakpointMapErrorMessage = exports.invalidBreakpointsErrorMessage = exports.composeError = exports.throwError = exports.InvalidValueError = undefined;

var _ramda = require('ramda');

var _const = require('./const');

var _features = require('./features');

var _string = require('./utils/string');

var keysToCommaSeparatedList = (0, _ramda.compose)(_string.toCommaSeparatedList, _ramda.keys);
var valuesToCommaSeparatedList = (0, _ramda.compose)(_string.toCommaSeparatedList, _ramda.values);
var objectToString = JSON.stringify;

// Horrible hackery to get round issues with Babel extending builtins.
// This is the only way to have a custom error.
var InvalidValueError = function InvalidValueError(message) {
  var error = new Error(message);
  error.name = 'InvalidValueError';
  this.name = error.name;
  this.message = error.message;
  if (error.stack) this.stack = error.stack;
  this.toString = function () {
    return this.name + ': ' + this.message;
  };
};
InvalidValueError.prototype = new Error();
InvalidValueError.prototype.name = 'InvalidValueError';

// -----------------------------------------------------------------------------
// Exports
// -----------------------------------------------------------------------------

exports.InvalidValueError = InvalidValueError;
var throwError = exports.throwError = function throwError(message) {
  throw new InvalidValueError(message);
};

var composeError = exports.composeError = function composeError(message) {
  return (0, _ramda.compose)(throwError, message);
};

var invalidBreakpointsErrorMessage = exports.invalidBreakpointsErrorMessage = function invalidBreakpointsErrorMessage(breakpoints) {
  return 'The breakpoints object must be an object, but you supplied \'' + objectToString(breakpoints) + '\'';
};

var emptyBreakpointMapErrorMessage = exports.emptyBreakpointMapErrorMessage = function emptyBreakpointMapErrorMessage(breakpointMap) {
  return '\n  You must not supply an empty object of breakpoints \'configure()\', but the you supplied \'' + objectToString(breakpointMap) + '\'.';
};

var invalidBreakpointNamesErrorMessage = exports.invalidBreakpointNamesErrorMessage = function invalidBreakpointNamesErrorMessage(breakpointMap) {
  return 'You supplied a breakpoint set with an invalid name. Valid values are: \'' + _features.rangedFeatureNames + '\'. but you supplied: \'' + objectToString(breakpointMap) + '\'.';
};

var emptyBreakpointSetErrorMessage = exports.emptyBreakpointSetErrorMessage = function emptyBreakpointSetErrorMessage(breakpointMapName) {
  return 'A breakpoint set must contain at least one breakpoint, but you supplied an empty breakpoint map for the \'' + objectToString(breakpointMapName) + '\' map.';
};

var mssingBreakpointMapErrorMessage = exports.mssingBreakpointMapErrorMessage = function mssingBreakpointMapErrorMessage(name) {
  return 'There is no breakpoint map for ' + name;
};

var missingBreakpointErrorMessage = exports.missingBreakpointErrorMessage = (0, _ramda.curry)(function (name, breakpointMapName, breakpointMaps) {
  return 'There is no \'' + breakpointMapName + '\' breakpoint defined called \'' + name + '\', only: \'' + keysToCommaSeparatedList(breakpointMaps) + '\' are defined.';
});

var sameBreakpointsForBetweenErrorMessage = exports.sameBreakpointsForBetweenErrorMessage = function sameBreakpointsForBetweenErrorMessage(name) {
  return 'You must supply two different breakpoints to \'widthBetween\' but both were: \'' + name + '\'.';
};

var invalidMediaTypeErrorMessage = exports.invalidMediaTypeErrorMessage = function invalidMediaTypeErrorMessage(value) {
  return '\'mediaType\' must be one of \'' + valuesToCommaSeparatedList(_const.MEDIA_TYPES) + '\' but you supplied: \'' + value + '\'.';
};

var invalidBreakpointSetValueErrorMessage = exports.invalidBreakpointSetValueErrorMessage = (0, _ramda.curry)(function (message, breakpoints) {
  return message + ' but you supplied ' + objectToString(breakpoints);
});

var invalidBaseFontSizeErrorMessage = exports.invalidBaseFontSizeErrorMessage = function invalidBaseFontSizeErrorMessage(value) {
  return '\'baseFontSize\' must be a positive number, but you supplied \'' + value + '\'';
};

var invalidDefaultMediaTypeErrorMessage = exports.invalidDefaultMediaTypeErrorMessage = function invalidDefaultMediaTypeErrorMessage(value) {
  return '\'defaultMediaType\' must be one of \'' + valuesToCommaSeparatedList(_const.MEDIA_TYPES) + '\' but was \'' + value + '\'.';
};

var invalidDimensionsUnitErrorMessage = exports.invalidDimensionsUnitErrorMessage = function invalidDimensionsUnitErrorMessage(value) {
  return '\'unit\' must be one of \'' + valuesToCommaSeparatedList(_const.UNITS.DIMENSIONS) + '\' but was \'' + value + '\'.';
};

var shouldSeparateQueriesErrorMessage = exports.shouldSeparateQueriesErrorMessage = function shouldSeparateQueriesErrorMessage(value) {
  return '\'shouldSeparateQueries\' must be a boolean but was \'' + value + '\'.';
};

var invalidFeatureErrorMessage = exports.invalidFeatureErrorMessage = (0, _ramda.curry)(function (name, possibleValues, value) {
  return '\n  \'' + name + '\' must be one of: \'' + possibleValues + '\' but was: \'' + value + '\'.';
});

var queryNoElementsErrorMessage = exports.queryNoElementsErrorMessage = function queryNoElementsErrorMessage() {
  return "You must supply at least one argument to 'query()' to build a valid media query";
};

var queryElementIsValidTypeErrorMessage = exports.queryElementIsValidTypeErrorMessage = function queryElementIsValidTypeErrorMessage(value) {
  return 'You must only supply strings or arrays to \'query()\' but you supplied \'' + value + '\'';
};

var queryChildElementIsValidTypeErrorMessage = exports.queryChildElementIsValidTypeErrorMessage = function queryChildElementIsValidTypeErrorMessage(value) {
  return 'You must only supply strings or arrays as children of arrays passed in to \'query()\' but you supplied \'' + objectToString(value) + '\'';
};

var queryNoNestedArraysErrorMessage = exports.queryNoNestedArraysErrorMessage = function queryNoNestedArraysErrorMessage(value) {
  return 'You must not supply any nested arrays to \'query()\' but you supplied \'' + value + '\'';
};

var noUntweakedErrorMessage = exports.noUntweakedErrorMessage = function noUntweakedErrorMessage() {
  return 'There is no untweaked mq object available';
};